==> haskell-text-builder-dev-0.3.3.2-94-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-builder-dev.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-builder-dev
version:              0.3.3.2
visibility:           public
id:                   text-builder-dev-0.3.3.2-22W422lTnvb6XH37orzNV0
key:                  text-builder-dev-0.3.3.2-22W422lTnvb6XH37orzNV0
license:              MIT
copyright:            (c) 2022, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/text-builder-dev
synopsis:             Edge of developments for "text-builder"
description:
    This is a development version of \"text-builder\".
    All experimentation and feature development happens here.
    The API can change drastically.
    For a more stable API use \"text-builder\",
    which is now just a wrapper over this package.

category:             Text
abi:                  6c212c3d7a9339d0ac8696082a496a6c
exposed:              True
exposed-modules:      TextBuilderDev
hidden-modules:
    TextBuilderDev.Allocator TextBuilderDev.Unicode
    TextBuilderDev.Utf16View TextBuilderDev.Utf8View
    TextBuilderDev.Prelude

import-dirs:          /usr/lib/ghc-9.2.8/site-local/text-builder-dev-0.3.3.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/text-builder-dev-0.3.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-builder-dev
hs-libraries:         HStext-builder-dev-0.3.3.2-22W422lTnvb6XH37orzNV0
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    deferred-folds-0.9.18.6-2hROn07hzyWBmHh6LH1egA
    isomorphism-class-0.1.0.11-HXUudPyCqr0IYBOBL2wagG
    split-0.2.5-3yHGsS1jHoyLHpkVbnU0Aa text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-text-builder-dev/html/text-builder-dev.haddock

haddock-html:         /usr/share/doc/haskell-text-builder-dev/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-builder-dev-0.3.3.2-95-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-builder-dev.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-builder-dev
version:              0.3.3.2
visibility:           public
id:                   text-builder-dev-0.3.3.2-Ce9UPdLDujmLcYlApwoUTw
key:                  text-builder-dev-0.3.3.2-Ce9UPdLDujmLcYlApwoUTw
license:              MIT
copyright:            (c) 2022, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/text-builder-dev
synopsis:             Edge of developments for "text-builder"
description:
    This is a development version of \"text-builder\".
    All experimentation and feature development happens here.
    The API can change drastically.
    For a more stable API use \"text-builder\",
    which is now just a wrapper over this package.

category:             Text
abi:                  8c10efc4ae585e1459de9dfb9c8904f6
exposed:              True
exposed-modules:      TextBuilderDev
hidden-modules:
    TextBuilderDev.Allocator TextBuilderDev.Unicode
    TextBuilderDev.Utf16View TextBuilderDev.Utf8View
    TextBuilderDev.Prelude

import-dirs:          /usr/lib/ghc-9.2.8/site-local/text-builder-dev-0.3.3.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/text-builder-dev-0.3.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-builder-dev
hs-libraries:         HStext-builder-dev-0.3.3.2-Ce9UPdLDujmLcYlApwoUTw
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    deferred-folds-0.9.18.6-6I6oV2NBzd5HfsPBZXcton
    isomorphism-class-0.1.0.11-F3oYeVzFh5PI6ZHBuQQazT
    split-0.2.5-3yHGsS1jHoyLHpkVbnU0Aa text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-text-builder-dev/html/text-builder-dev.haddock

haddock-html:         /usr/share/doc/haskell-text-builder-dev/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
